xray

package module
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 22, 2024 License: Apache-2.0 Imports: 11 Imported by: 0

README

XRay

XRay is a open source library for database schema extraction and query execution.

Install

go get github.com/thesaas-company/xray@latest

Docs

Install xRay cli
Linux
curl -sL https://raw.githubusercontent.com/thesaas-company/xray/main/install.sh |  sudo bash -s -- -b /usr/local/bin
MacOS
brew install thesaas-company/homebrew-tap/xray
Supported Databases

logo-mysql-170x115 google_bigquery_logo_icon_168151 postgresql_plain_wordmark_logo_icon_146390 snowflake_logo_icon_168808 (2) 1669818522440 5968364

Deployment

Show Your Support!

If you find XRay useful, please consider starring the repository on GitHub to show your support:

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewClient

func NewClient(dbClient *sql.DB, dbType types.DbType) (types.ISQL, error)

NewClient creates a new SQL client with the given database client and database type. It returns an error if the database type is not supported or if there is a problem creating the client.

func NewClientWithConfig

func NewClientWithConfig(dbConfig *config.Config, dbType types.DbType) (types.ISQL, error)

NewClientWithConfig creates a new SQL client with the given configuration and database type. It returns an error if the database type is not supported or if there is a problem creating the client.

Types

This section is empty.

Directories

Path Synopsis
cli
cmd
databases
example
bigquery command
mssql command
mysql command
postgres command
redshift command
snowflake command
Package logger provides a logging wrapper for the ISQL interface.
Package logger provides a logging wrapper for the ISQL interface.

Jump to